     
      /*##############################################################
      #  DAILY CHANGE INDICATOR                                      #
      #                                                              #
      #  This Indicator shows the percentage change between          #
      #  yesterday day close and today actual Price (Bid).           #
      #  It works on any time frame.                                 #
      #                                                              #
      #                                                              #
      ##############################################################*/

/*
------------------------------------------------------------------------------------------------

Description:
 
This indicator shows the % Daily Change of yesterday close with respect to actual price (Bid). 

It calculates the percentage change between yesterday close price and the actual bid price. 

It works on any timeframe.


External Modifications:

You can modify the color and size:

Color:         You can change the color for Up Movement, Down Movement and No Movement      
Size:          You can change the text font size and the arrow size   

You can modify the position of text and arrow:

X_Position           You can modify X position (distance) from corner
Y_Position           You can modify Y position (distance) from corner
Corner_Position      You can select the corner position (0: Top Left / 1: Top Right / 2: Bottom Left / 3: Bottom Right)

------------------------------------------------------------------------------------------------
*/


#property indicator_chart_window

//---------------------------------------------------- 
extern int     Font_Size               = 12;
extern int     Arrow_Size              = 14;
extern color   Up_Color                = Lime;
extern color   Down_Color              = Red;
extern color   No_Mvt_Color            = Gold;

extern int     X_Position_Text         = 20;
extern int     Y_Position_Text         = 20;
extern int     Corner_Position_Text    = 1;

extern int     X_Position_Arrow        = 20;
extern int     Y_Position_Arrow        = 100;
extern int     Corner_Position_Arrow   = 1;
// ---------------------------------------------------

#define OBJECT    "DailyChange"
#define OBJECT1   "ArrowChange"
#define OBJECT2   "Open-Low"
#define OBJECT3   "Open=High"
#define OBJECT4   "Price above Open"
#define OBJECT5   "Price below Open"
#define OBJECT6   "TodayHigh"
#define OBJECT7   "TodayOpen"
#define OBJECT8   "TodayLow"
#define OBJECT9   "TodayCurrent"
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = false;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = false;
extern bool   alertsEmail     = false;



int start()

   {

   double PH = iHigh(Symbol(),PERIOD_D1,1);
   double PL = iLow(Symbol(),PERIOD_D1,1);
   double TO = iOpen(Symbol(),PERIOD_D1,0);
   double TH = iHigh(Symbol(),PERIOD_D1,0);
   double TL = iLow(Symbol(),PERIOD_D1,0);
   double ClPrice_D1    = iClose(NULL, PERIOD_D1, 1);
   double ActualBid     = Bid;
   double PercChange    = ((ActualBid - ClPrice_D1)/ClPrice_D1)*100;
   
   
   double WH = iHigh(Symbol(),PERIOD_W1,1);
   double WL = iLow(Symbol(),PERIOD_W1,1);
   double WC = iClose(Symbol(),PERIOD_W1,0);
   
   double WP = (WH+ WL + WC)/3;

   
   
   double P = (PH+ PL + ClPrice_D1)/3;

   string ArrowUp       =  "p";  // 112 Up arrow code
   string ArrowDn       =  "q";  // 113 Down arrow code
   string Arrow0        =  "";
   string Arrow;
   color  Obj_Color;
   
   string PerChg = ":- "+DoubleToStr(PercChange, 2) + " %";
   
   if(PercChange > 0)   {Arrow = ArrowUp; Obj_Color = Up_Color;}
   if(PercChange < 0)   {Arrow = ArrowDn; Obj_Color = Down_Color;}
   if(PercChange == 0)  {Arrow = Arrow0; Obj_Color = No_Mvt_Color;}
   
   
   string ArrowChg = Arrow;
     
   if(ObjectFind(OBJECT) < 0)
      
      {
      ObjectCreate   (OBJECT, OBJ_LABEL, 0, 0, 0);
      ObjectSet      (OBJECT, OBJPROP_CORNER, Corner_Position_Text);
      ObjectSet      (OBJECT, OBJPROP_YDISTANCE, X_Position_Text);
      ObjectSet      (OBJECT, OBJPROP_XDISTANCE, Y_Position_Text);
      ObjectSetText  (OBJECT, PerChg, Font_Size, "Verdana", Obj_Color);
      } 
   
   ObjectSetText(OBJECT, PerChg, Font_Size, "Verdana", Obj_Color); 

  if(ObjectFind(OBJECT1) < 0)
      
      {
      ObjectCreate   (OBJECT1, OBJ_LABEL, 0, 0, 0);
      ObjectSet      (OBJECT1, OBJPROP_CORNER, Corner_Position_Arrow);
      ObjectSet      (OBJECT1, OBJPROP_YDISTANCE, X_Position_Arrow);
      ObjectSet      (OBJECT1, OBJPROP_XDISTANCE, Y_Position_Arrow);
      ObjectSetText  (OBJECT1, ArrowChg, Arrow_Size, "Wingdings 3", Obj_Color);
      } 
   
   ObjectSetText(OBJECT1, ArrowChg, Arrow_Size, "Wingdings 3", Obj_Color);  
   
  //------------------------------------------------------ 
   
   // CO RELATION OF OPEN WITH HIGH
   
   
   
   {
    ObjectCreate(OBJECT6, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT6, "High - " +DoubleToStr(TH, 2), 12, "Arial", LimeGreen);
    ObjectSet(OBJECT6, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT6, OBJPROP_XDISTANCE, 2);
    ObjectSet(OBJECT6, OBJPROP_YDISTANCE, 120); 
    }
     
      
   {
    ObjectCreate(OBJECT7, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT7, "Open - " +DoubleToStr(TO, 2), 12, "Arial", Yellow);
    ObjectSet(OBJECT7, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT7, OBJPROP_XDISTANCE, 2);
    ObjectSet(OBJECT7, OBJPROP_YDISTANCE, 140); 
    }
     
       
   
   
   {
    ObjectCreate(OBJECT8, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT8, "Low - " +DoubleToStr(TL, 2), 12, "Arial", OrangeRed);
    ObjectSet(OBJECT8, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT8, OBJPROP_XDISTANCE, 2);
    ObjectSet(OBJECT8, OBJPROP_YDISTANCE, 160); 
    }
    
   {
    ObjectCreate(OBJECT9, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT9, "Close - " +DoubleToStr(ActualBid, 2), 12, "Arial", YellowGreen);
    ObjectSet(OBJECT9, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT9, OBJPROP_XDISTANCE, 2);
    ObjectSet(OBJECT9, OBJPROP_YDISTANCE, 180); 
    }
    
  
   //--------------------------------------------------------
   {
   if (TO==TL)

    { 
    ObjectCreate(OBJECT2, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT2, "OPEN=LOW--BUY "  , 12, "Arial Bold", LimeGreen);
    ObjectSet(OBJECT2, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT2, OBJPROP_XDISTANCE, 500);
    ObjectSet(OBJECT2, OBJPROP_YDISTANCE, 20); 
    }
      
   else if(TO==TH)
   
    {
    ObjectCreate(OBJECT3, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT3, "OPEN=HIGH--SELL " , 12, "Arial Bold", OrangeRed);
    ObjectSet(OBJECT3, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT3, OBJPROP_XDISTANCE, 500);
    ObjectSet(OBJECT3, OBJPROP_YDISTANCE, 20); 
    }
    else 
    {

     ObjectSetText(OBJECT3, "RANGE " , 12, "Arial Bold", Yellow);
   }
  }
     
  //-----------------------------------------------------------  
  {
   if (ActualBid>TO)
    
    { 
    ObjectCreate(OBJECT4, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT4, "Price Above Open--BUY "  , 12, "Arial", LimeGreen);
    ObjectSet(OBJECT4, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT4, OBJPROP_XDISTANCE, 500);
    ObjectSet(OBJECT4, OBJPROP_YDISTANCE, 40); 
    }
      
   else if(ActualBid<TO)
   
    {
    ObjectCreate(OBJECT5, OBJ_LABEL, 0, 0, 0);
    ObjectSetText(OBJECT5, "Price Below Open--SELL " , 12, "Arial", OrangeRed);
    ObjectSet(OBJECT5, OBJPROP_CORNER, 1);
    ObjectSet(OBJECT5, OBJPROP_XDISTANCE, 500);
    ObjectSet(OBJECT5, OBJPROP_YDISTANCE, 40); 
    }
   }
   
   
   
   WindowRedraw();
   
     
   
   return(0);   

}


 


//--- INIT AND DEINIT ------------------------------------- //

int init()
{
   return(0);   
}


int deinit()
{
   ObjectDelete(OBJECT);
   ObjectDelete(OBJECT1);
   ObjectDelete(OBJECT2);
   ObjectDelete(OBJECT3);
   ObjectDelete(OBJECT4);
   ObjectDelete(OBJECT5);
   ObjectDelete(OBJECT6);
   ObjectDelete(OBJECT7);
   ObjectDelete(OBJECT8);
   ObjectDelete(OBJECT9);
   return(0);   
}



//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void manageAlerts()
{
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      double open = ObjectGet(OBJECT7,OBJPROP_PRICE1);
         if (Close[whichBar]>open && Close[whichBar+1]<open) doAlert("above");
         if (Close[whichBar]>open && Close[whichBar+1]>open) doAlert("bellow");
   }
}

//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   string message;
   
   if (previousAlert != doWhat) {
       previousAlert  = doWhat;

       //
       //
       //
       //
       //

       message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Daily OHLC close crossed ",doWhat," open");
          if (alertsMessage) Alert(message);
          if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Daily OHLC "),message);
          if (alertsSound)   PlaySound("alert2.wav");
   }
}